@@ -1,4 +1,5 @@
 from pioneer.das.api.datasources.virtual_datasources.virtual_datasource import VirtualDatasource
+from pioneer.das.api.datasources.virtual_datasources.bounding_box_metadata import BoundingBoxMetadata
 from pioneer.das.api.datasources.virtual_datasources.cylindrical_projection import FlirCylindricalProjection
 from pioneer.das.api.datasources.virtual_datasources.echoes_from_traces import Echoes_from_Traces
 from pioneer.das.api.datasources.virtual_datasources.echoes_with_pulses import EchoesWithPulses
@@ -9,6 +10,7 @@ from pioneer.das.api.datasources.virtual_datasources.waveform_cloud import Wavef
 from pioneer.das.api.datasources.virtual_datasources.voxel_map import VoxelMap
 
 VIRTUAL_DATASOURCE_FACTORY = {
+    'bounding_box_metadata': BoundingBoxMetadata,
     'cylindrical_projection': FlirCylindricalProjection,
     'echoes_from_traces': Echoes_from_Traces,
     'echoes_with_pulses': EchoesWithPulses,
