@@ -1,4 +1,4 @@
 from pioneer.das.api.egomotion.egomotion_provider import EgomotionProvider
 from pioneer.das.api.egomotion.carla_egomotion_provider import CarlaEgomotionProvider
-from pioneer.das.api.egomotion.encoder_egomotion_provider import EncoderEgomotionProvider
-from pioneer.das.api.egomotion.imu_egomotion_provider import IMUEgomotionProvider
\ No newline at end of file
+from pioneer.das.api.egomotion.imu_egomotion_provider import IMUEgomotionProvider
+from pioneer.das.api.egomotion.vaya_egomotion_provider import VayaEgomotionProvider
\ No newline at end of file
