@@ -2,12 +2,13 @@ from pioneer.common import platform as platform_utils
 from pioneer.common.logging_manager import LoggingManager
 from pioneer.das.api.datasources import AbstractDatasource
 from pioneer.das.api.datasources import virtual_datasources
+from pioneer.das.api.egomotion import EgomotionProvider
 from pioneer.das.api.samples.sample import Sample
 from pioneer.das.api.sensors import Sensor
 from pioneer.das.api.sensors import SENSOR_FACTORY
 from pioneer.das.api.sources import DirSource, ZipFileSource
 
-from typing import Callable, Iterator, Union, Optional, List, Dict, Mapping, Tuple, Any
+from typing import Iterator, Union, Optional, List, Dict, Mapping, Tuple, Any
 
 import ast
 import glob
@@ -70,8 +71,8 @@ def closest_timestamps_np(ref_ts:np.ndarray, target_ts:np.ndarray, tol:Union[flo
 closest_timestamps = closest_timestamps_np
 
 if HAVE_NUMBA:
-    @numba.njit
-    def closest_timestamps_numba(ref_ts, target_ts, tol):
+    @numba.njit(cache=True)
+    def closest_timestamps_numba(ref_ts:np.ndarray, target_ts:np.ndarray, tol:Union[float, int]):
         """ Numba-optimized version of closest_timestamps_np()"""
         n_ref = ref_ts.shape[0]
         ref_ts = ref_ts.astype(np.int64)
@@ -89,13 +90,14 @@ if HAVE_NUMBA:
         
     closest_timestamps = closest_timestamps_numba
 
-class Platform(object):
+class Platform:
     """A Platform is what encapsulate an instance (configuration) of some data acquisition platform. 
        It contains one or more sensors, each containing one or more datasources. A live platform interfaces
        live sensors, while an offline platform can be used to extract data from a recording. 
     """
 
-    def __init__(self, dataset:Optional[str]=None, configuration:Optional[str]=None, include:Optional[list]=None, ignore:Optional[list]=[], progress_bar:bool=True, default_cache_size:int=100):
+    def __init__(self, dataset:Optional[str]=None, configuration:Optional[str]=None, include:Optional[list]=None, ignore:Optional[list]=[],
+     progress_bar:bool=True, default_cache_size:int=100, activate_logger:bool=False):
         """Constructor
 
            Args:
@@ -118,6 +120,8 @@ class Platform(object):
             default_cache_size: the default value for (offline) datasource cache size
         """
 
+        LoggingManager.instance().set_verbosity(activate_logger)
+
         self.dataset = dataset
         self.progress_bar = progress_bar
         self.default_cache_size = default_cache_size
@@ -194,7 +198,7 @@ class Platform(object):
 
         return os.path.join(self.dataset, relative_path)
 
-    def try_absolute_or_relative(self, folder):
+    def try_absolute_or_relative(self, folder:str) -> str:
         """ tries for absolute or relative path """
 
         folder_path = self.to_nas_path(folder)
@@ -266,7 +270,7 @@ class Platform(object):
             except: pass
     
     @property
-    def egomotion_provider(self) -> 'EgomotionProvider':
+    def egomotion_provider(self) -> EgomotionProvider:
         return self._sensors._egomotion_provider
 
     def datasource_names(self) -> List[str]:
@@ -276,7 +280,12 @@ class Platform(object):
             ds_names.extend(s.datasource_names())
         return ds_names
 
-    def add_virtual_datasources(self, virtual_datasources_config):
+    def add_egomotion_provider(self, egomotion_provider:EgomotionProvider):
+        self[egomotion_provider._referential_name].egomotion_provider = egomotion_provider
+        self._sensors._egomotion_provider = egomotion_provider
+        egomotion_provider.sensor = self[egomotion_provider._referential_name]
+
+    def add_virtual_datasources(self, virtual_datasources_config:Dict[str, Dict]):
         """Add virtual datasources based upon the provided configuration dictionnary
         
             Args:
@@ -339,7 +348,7 @@ class Platform(object):
             raise IndexError('Invalid label: {}'.format(label))
 
 
-class Synchronized(object):
+class Synchronized:
     """Synchronized view over a Platform"""
 
     def __init__(self, platform:Platform, sync_labels:List[str], interp_labels:List[str], tolerance_us:Union[float, int], fifo:int):
@@ -435,7 +444,7 @@ class Synchronized(object):
 
             raise KeyError("Unsupported key type: {}".format(index))
     
-    class SynchGetter(object):
+    class SynchGetter:
         def __init__(self, index, synch):
             self.index = index
             self.synch = synch
@@ -480,15 +489,6 @@ class Synchronized(object):
             return iter(self.values())
 
     def __getitem__(self, index:Union[int, slice, Iterator[int]]) ->Dict[str, Sample]:
-        """Implements the '[]' API
-
-            Args:
-                index: the (complete) datasource name
-            Returns:
-                A Sample
-
-        """
-        
         return Synchronized.SynchGetter(index, self)
 
     def timestamps(self, index:int) -> np.ndarray:
@@ -701,7 +701,7 @@ class SynchronizedGroup(Synchronized):
 
 
 
-class Filtered(object):
+class Filtered:
 
     def __init__(self, synchronized:Synchronized, indices:List[int]):
         self.synchronized = synchronized
@@ -739,7 +739,7 @@ class Filtered(object):
         return self.synchronized[self.indices[index]]
         
 
-class Sliced(object):
+class Sliced:
     """Creates a view on a synchronized dataset using a list of intervals"""
 
     def __init__(self, synchronized:Synchronized, intervals:List[Tuple[int, int]], stride:int = 1):
@@ -799,7 +799,7 @@ class Sliced(object):
         return self.synchronized[self.indices[index]]
 
 
-class Sensors(object):
+class Sensors:
     """The collection of Sensor instances in a platform"""
     def __init__(self, pf:'Platform', yml:dict):
         """Constructor
@@ -818,10 +818,7 @@ class Sensors(object):
         for name, value in yml_items_tqdm:
 
             sensor_type, _ = platform_utils.parse_sensor_name(name)
-            if sensor_type in SENSOR_FACTORY:
-                self._sensors[name] = SENSOR_FACTORY[sensor_type](name, self.platform)
-            else:
-                self._sensors[name] = Sensor(name, self.platform)
+            self._sensors[name] = SENSOR_FACTORY.get(sensor_type, Sensor)(name, self.platform)
             self._ordered_names.append(name)
 
             self._load_offline_datasources(name)
@@ -840,8 +837,12 @@ class Sensors(object):
             if 'extrinsics' in value:
                 self._load_extrinsics(name, value['extrinsics'])
 
+        self.__add_egomotion_provider()
+
+    def __add_egomotion_provider(self):
+        for name, sensor in self.items():
             try:
-                provider = self._sensors[name].create_egomotion_provider()
+                provider = sensor.create_egomotion_provider()
             except:
                 LoggingManager.instance().warning(f"The 'egomotion_provider' for sensor name {name} could not be created.")
 
@@ -850,17 +851,6 @@ class Sensors(object):
                     LoggingManager.instance().warning(f"Another 'egomotion_provider' found for sensor name {name}, ignoring it.")
                 else:
                     self._egomotion_provider = provider
-
-
-    def start(self):
-        """**Live platform only** starts the (live) sensors"""
-        for name, sensor in self._sensors.items():
-            sensor.start()
-
-    def stop(self):
-        """**Live platform only** starts the (live) sensors"""
-        for name, sensor in self._sensors.items():
-            sensor.stop()
     
     def _load_intrinsics(self, name, intrinsics_config):
         """Intrinsics config can be a string or a dict so complete the path,
@@ -951,7 +941,7 @@ class Sensors(object):
     def __len__(self):
         return len(self._sensors)
 
-    def __getitem__(self, label):
+    def __getitem__(self, label:str):
         """Implement '[]' API"""
         return self._sensors[label]
 
