@@ -1,13 +1,11 @@
 from pioneer.das.api.samples.annotations import *
 from pioneer.das.api.samples.echo import Echo
-from pioneer.das.api.samples.echo_xyzit import EchoXYZIT
 from pioneer.das.api.samples.fast_trace import FastTrace
 from pioneer.das.api.samples.image import Image
 from pioneer.das.api.samples.image_cylinder import ImageCylinder
 from pioneer.das.api.samples.image_fisheye import ImageFisheye
-from pioneer.das.api.samples.rpm import RPM
+from pioneer.das.api.samples.point_cloud import PointCloud
 from pioneer.das.api.samples.sample import Sample
 from pioneer.das.api.samples.trace import Trace
 from pioneer.das.api.samples.xyzit import XYZIT
-from pioneer.das.api.samples.xyzvcfar import XYZVCFAR
-from pioneer.das.api.samples.xyzvi import XYZVI
\ No newline at end of file
+from pioneer.das.api.samples.xyzv import XYZV
