@@ -1,14 +1,16 @@
 from pioneer.das.api.sensors.sensor import Sensor
+from pioneer.das.api.sensors.sensor3d import Sensor3D
+from pioneer.das.api.sensors.lidar import Lidar
+from pioneer.das.api.sensors.radar import Radar
 from pioneer.das.api.sensors.pixell import Pixell
 from pioneer.das.api.sensors.motor_lidar import MotorLidar
 from pioneer.das.api.sensors.camera import Camera
 from pioneer.das.api.sensors.imu_sbg_ekinox import ImuSbgEkinox
-from pioneer.das.api.sensors.encoder import Encoder
 from pioneer.das.api.sensors.carla_imu import CarlaIMU 
-from pioneer.das.api.sensors.radar_ti import RadarTI
-from pioneer.das.api.sensors.radar_conti import RadarConti
 from pioneer.das.api.sensors.lcax import LCAx
 from pioneer.das.api.sensors.lca3 import LCA3
+from pioneer.das.api.sensors.gps_vaya import GPSVaya
+
 
 
 SENSOR_FACTORY = {  
@@ -19,16 +21,13 @@ SENSOR_FACTORY = {
     'flir': Camera,
     'camera': Camera,
     'sbgekinox': ImuSbgEkinox,
-    'vlp16': MotorLidar,
+    'vlp16': Lidar,
     'ouster64': MotorLidar,
-    'peakcan': Sensor,
-    'radarTI': RadarTI,
-    'radarConti': RadarConti,
+    'radarTI': Radar,
+    'radarConti': Radar,
     'webcam': Camera,
-    'encoder': Encoder,
     'carlaimu': CarlaIMU,
     'leddar': LCAx,
-    'lidar': MotorLidar,
-    'any': Sensor,
-    'manual': Sensor,
+    'lidar': Lidar,
+    'gpsvaya': GPSVaya,
 }
\ No newline at end of file
