@@ -3,11 +3,13 @@ from pioneer.das.api.samples import Sample
 from pioneer.das.api.sensors.sensor import Sensor
 from pioneer.das.api.egomotion.carla_egomotion_provider import CarlaEgomotionProvider
 
+
+
 class CarlaIMU(Sensor):
-    def __init__(self, name, platform):
+    def __init__(self, name: str, platform: 'Platform'):
         factories = {'agc':(Sample, linear_ndarray_interpolator)}
-        super(CarlaIMU, self).__init__(name, platform, factories)
+        super().__init__(name, platform, factories)
 
     def create_egomotion_provider(self):
-        self.egomotion_provider = CarlaEgomotionProvider(self.name, self)
-        return self.egomotion_provider
\ No newline at end of file
+        self.egomotion_provider = CarlaEgomotionProvider(self.name, self["agc"])
+        return self.egomotion_provider
